%% mainMultiUnderlAssets

% Calibrates a volatility model using Techila Distributed Computing Engine.
clear all; clc; close all
disp('Starting Approach A version...')
disp('In this version, a new computational Project will be created each time the objective function is called.')
path = cd;
addpath(genpath(path));

%% Settings
settings = calibrationSettings;

%% Input data (volatility surfaces)
% struct: data
% Fields: T (time to maturity), K (strike price), r (interest rate), S0
% (underlying price)
% Additional fields (not used in calibration but in the verification of 
% calibration): callPrices (actual call option prices), IVol (actual
% implied volatility surface), parameters (actual parameters)

disp('Loading input data...')
load('empVolatilitySurfaceData2Years.mat'); 
disp('done.')

%% Initial parameters
kappa = 3; 
theta = 0.2^2; 
xi = 1; 
rho = -0.8;
V0 = 0.18^2;
gamma = 0.5;
parametersInitialVect = [kappa; theta; xi; rho; V0; gamma];


%% Calibrate model
f = @(x)pricingError2(data, settings, x);

% Initialize connection to Techila Server. This will only be done once,
% subsequent Project creations will use this same initialization to
% minimize overheads.
techilainit;
try
    disp('Starting calibration (fminsearch) process in TDCE...')
    [parametersFinalVect, fFinal, exitFlag] = fminsearch(f, parametersInitialVect, settings.calibrOptions);
    disp('Completed calibration (fminsearch).')
catch ME
    disp('Error in calibration (fminsearch)');
    disp('--------------------------------');
    disp(['Error identifier: ', ME.identifier]);
    disp(['Error message: ', ME.message]);
    for n = 1:length(ME.stack)
        disp(' ');
        disp(['Function: ', ME.stack(n).name]);
        disp(['File: ', ME.stack(n).file]);
        disp(['Line number: ', num2str(ME.stack(n).line)]);
    end
    disp('--------------------------------');
    parametersFinalVect = NaN.*parametersInitialVect;
    fFinal = NaN;
    exitFlag = NaN;
end
% Uninitialize connection to Techila Server.
techilauninit;

kappaFinal = parametersFinalVect(1);
thetaFinal = parametersFinalVect(2);
xiFinal = parametersFinalVect(3);
rhoFinal= parametersFinalVect(4);
V0Final = parametersFinalVect(5);
gammaFinal = parametersFinalVect(6);