function res = ...
    pricingError2(data, settings, parametersVect)
% This function computes the option pricing error (IVRMSE) between model and market implied
% volatility surfaces.
%% Check that parameters are within boundaries

persistent iterationid
if isempty(iterationid)
    iterationid=0;
end

parameters.kappa = parametersVect(1);
parameters.theta = parametersVect(2);
parameters.xi = parametersVect(3);
parameters.rho = parametersVect(4);
parameters.V0 = parametersVect(5);
parameters.gamma = parametersVect(6);

inBounds = true;
    
if parameters.kappa < settings.minKappa || parameters.kappa > settings.maxKappa || ...
        parameters.theta < settings.minTheta || parameters.theta > settings.maxTheta || ...
        parameters.xi < settings.minXi || parameters.xi > settings.maxXi || ...
        parameters.rho < settings.minRho || parameters.rho > settings.maxRho || ...
        parameters.gamma < settings.minGamma || parameters.gamma > settings.maxGamma || ...
        parameters.V0 < settings.minV0 || parameters.V0 > settings.maxV0
    inBounds = false;
end

if inBounds
    %% Filtering option contracts with respect to strike prices
    indK = data.K >= settings.StrikeRange(1) & data.K <= settings.StrikeRange(2);
    K = data.K(indK);
    T = data.T(indK);
    r = data.r(indK);
    S0 = data.S0(indK);
    IVol = data.IVol(indK);
    
    iterationid = iterationid + 1;
    
    %% Pricing options
    
    % Cloudfor parameters explained:
    %
    %cloudfor('stepsperjob',1) - Calculate one iteration per Job
    %
    %cloudfor('donotinit') - Do not initializate the connection
    %
    %cloudfor('donotuninit') - Do not uninitialize the connection
    %
    %cloudfor('sum',callPricesModel) - Sum the values of 'callPricesModel'
    %
    %cloudfor('outputparam',callPricesModel) - Only return variable 'callPricesModel'
    
    
    numJobs = 20;
    cloudfor jobid=1:numJobs
    %cloudfor('stepsperjob',1)
    %cloudfor('donotinit')
    %cloudfor('donotuninit')
    %cloudfor('sum',callPricesModel)
    %cloudfor('outputparam',callPricesModel)
        settings.nSim = settings.nSim/numJobs;
        settings.seedNumber=jobid;
        callPricesModel = MonteCarloPricing(S0, K, r, T, parameters, ...
            settings.nSim, settings.seedNumber, settings.tradingDaysInYear);
    cloudend
    
    callPricesModel = callPricesModel / numJobs;  
    IVolModel = blsimpv(S0, K, r, T, callPricesModel);
    IVolModel(isnan(IVolModel)) = 0;

    %% Option pricing error
    res = 100*sqrt(mean((IVolModel - IVol).^2));

    %% Showing results
    plotSurface(res, parameters, K, T, IVolModel, IVol, settings, iterationid);        

else
    res = 1e10;
end
end
