%% mainMultiUnderlAssets
clear all; clc; close all
% Calibrates a volatility model using Techila Distributed Computing Engine
disp('Starting Approach B version...')
disp('In this version, only one computational Project will be created.')
disp('Techila Workers will transfer data using the Techila Interconnect feature.')



path = cd;
addpath(genpath(path));

%% Settings
settings = calibrationSettings;

%% Input data (volatility surfaces)
% struct: data
% Fields: T (time to maturity), K (strike price), r (interest rate), S0
% (underlying price)
% Additional fields (not used in calibration but in the verification of 
% calibration): callPrices (actual call option prices), IVol (actual
% implied volatility surface), parameters (actual parameters)

disp('Loading input data...')
load('empVolatilitySurfaceData2Years.mat'); 
disp('done.')

%% Initial parameters
kappa = 3; 
theta = 0.2^2; 
xi = 1; 
rho = -0.8;
V0 = 0.18^2;
gamma = 0.5;
parametersInitialVect = [kappa; theta; xi; rho; V0; gamma];


%% Calibrate model
numOfJobs=20;
disp('NOTE! In order for the Project to complete successfully, you will need')
disp(['to have atleast ' num2str(numOfJobs) ' Techila Worker CPU cores available.'])
disp('Starting calibration (fminsearch) process in TDCE...')

% Cloudfor parameters explained:
%
%cloudfor('stepsperjob',1) - Will process one iteration per Job
%
%cloudfor('imcallback','plotSurface(TECHILA_FOR_IMRESULT.res,TECHILA_FOR_IMRESULT.parameters, TECHILA_FOR_IMRESULT.K,TECHILA_FOR_IMRESULT.T, TECHILA_FOR_IMRESULT.IVolModel, TECHILA_FOR_IMRESULT.IVol, settings, TECHILA_FOR_IMRESULT.iterationid)')
% - When intermediate result data is received, execute the 'plotSurface'
%   callback function to update the graph.

cloudfor jobid=1:numOfJobs
%cloudfor('stepsperjob',1)
%cloudfor('imcallback','plotSurface(TECHILA_FOR_IMRESULT.res,TECHILA_FOR_IMRESULT.parameters, TECHILA_FOR_IMRESULT.K,TECHILA_FOR_IMRESULT.T, TECHILA_FOR_IMRESULT.IVolModel, TECHILA_FOR_IMRESULT.IVol, settings, TECHILA_FOR_IMRESULT.iterationid)')
if isdeployed
    initIC(60000); % Initialize interconnect network on Techila Workers 
    settings.seedNumber=jobid;
    settings.nSim=settings.nSim/numOfJobs;
    f = @(x)pricingError(data, settings, x);
    if jobid==1
        try
            % Job #1 will run the fminsearch routine.
            [parametersFinalVect, fFinal, exitFlag] = fminsearch(f, parametersInitialVect, settings.calibrOptions);
            
            % After fminsearch is completed, a termination signal will be 
            % sent to all other Jobs.
            cloudbc(-pi); 
        catch ME
            disp('Error in calibration (fminsearch)');
            disp('--------------------------------');
            disp(['Error identifier: ', ME.identifier]);
            disp(['Error message: ', ME.message]);
            for n = 1:length(ME.stack)
                disp(' ');
                disp(['Function: ', ME.stack(n).name]);
                disp(['File: ', ME.stack(n).file]);
                disp(['Line number: ', num2str(ME.stack(n).line)]);
            end
            disp('--------------------------------');
            parametersFinalVect = NaN.*parametersInitialVect;
            fFinal = NaN;
            exitFlag = NaN;
        end
    else
        % All other Jobs will execute 'pricingError' function.
        pricingError(data, settings, 0);
    end
end
cloudend
disp('Completed calibration (fminsearch).')

kappaFinal = parametersFinalVect(1);
thetaFinal = parametersFinalVect(2);
xiFinal = parametersFinalVect(3);
rhoFinal= parametersFinalVect(4);
V0Final = parametersFinalVect(5);
