function res = ...
    pricingError(data, settings, parametersVect)
% This function computes the option pricing error (IVRMSE) between model and market implied
% volatility surfaces.
%% Check that parameters are within boundaries

parameters.kappa = parametersVect(1);
parameters.theta = parametersVect(2);
parameters.xi = parametersVect(3);
parameters.rho = parametersVect(4);
parameters.V0 = parametersVect(5);
parameters.gamma = parametersVect(6);

inBounds = true;

if parameters.kappa < settings.minKappa || parameters.kappa > settings.maxKappa || ...
        parameters.theta < settings.minTheta || parameters.theta > settings.maxTheta || ...
        parameters.xi < settings.minXi || parameters.xi > settings.maxXi || ...
        parameters.rho < settings.minRho || parameters.rho > settings.maxRho || ...
        parameters.gamma < settings.minGamma || parameters.gamma > settings.maxGamma || ...
        parameters.V0 < settings.minV0 || parameters.V0 > settings.maxV0
    inBounds = false;
end

if inBounds
    %% Filtering option contracts with respect to strike prices
    indK = data.K >= settings.StrikeRange(1) & data.K <= settings.StrikeRange(2);
    K = data.K(indK);
    T = data.T(indK);
    r = data.r(indK);
    S0 = data.S0(indK);
    IVol = data.IVol(indK);

    %% Pricing options
    callPricesModel = MonteCarloPricing(S0, K, r, T, parameters, ...
        settings.nSim, settings.seedNumber, settings.tradingDaysInYear);
    IVolModel = blsimpv(S0, K, r, T, callPricesModel);
    IVolModel(isnan(IVolModel)) = 0;

    %% Option pricing error
    res = 100*sqrt(mean((IVolModel - IVol).^2));
    
    %% Showing results
    plotSurface(res, parameters, K, T, IVolModel, IVol, settings, 0);

    
else
    res = 1e10;
end




end

